@@ -31,9 +31,9 @@ class ImapInterval::Private : public QSharedData
 {
   public:
     Private()
-      : QSharedData(),
-        begin( 0 ),
-        end( 0 )
+      : QSharedData()
+      , begin( 0 )
+      , end( 0 )
     {
     }
 
@@ -65,9 +65,8 @@ class ImapSet::Private : public QSharedData
     ImapInterval::List intervals;
 };
 
-
-ImapInterval::ImapInterval() :
-    d( new Private )
+ImapInterval::ImapInterval()
+  : d( new Private )
 {
 }
 
@@ -87,30 +86,32 @@ ImapInterval::~ImapInterval()
 {
 }
 
-ImapInterval& ImapInterval::operator=( const ImapInterval &other )
+ImapInterval &ImapInterval::operator=( const ImapInterval &other )
 {
-  if ( this != &other )
+  if ( this != &other ) {
     d = other.d;
+  }
 
   return *this;
 }
 
 bool ImapInterval::operator==( const ImapInterval &other ) const
 {
-  return (d->begin == other.d->begin && d->end == other.d->end);
+  return ( d->begin == other.d->begin && d->end == other.d->end );
 }
 
 ImapInterval::Id ImapInterval::size() const
 {
-  if ( !d->begin && !d->end )
+  if ( !d->begin && !d->end ) {
     return 0;
+  }
 
-  return (d->end - d->begin + 1);
+  return ( d->end - d->begin + 1 );
 }
 
 bool ImapInterval::hasDefinedBegin() const
 {
-  return (d->begin != 0);
+  return ( d->begin != 0 );
 }
 
 ImapInterval::Id ImapInterval::begin() const
@@ -120,13 +121,14 @@ ImapInterval::Id ImapInterval::begin() const
 
 bool ImapInterval::hasDefinedEnd() const
 {
-  return (d->end != 0);
+  return ( d->end != 0 );
 }
 
 ImapInterval::Id ImapInterval::end() const
 {
-  if ( hasDefinedEnd() )
+  if ( hasDefinedEnd() ) {
     return d->end;
+  }
 
   return std::numeric_limits<Id>::max();
 }
@@ -147,24 +149,26 @@ void ImapInterval::setEnd( Id value )
 
 QByteArray Akonadi::ImapInterval::toImapSequence() const
 {
-  if ( size() == 0 )
+  if ( size() == 0 ) {
     return QByteArray();
+  }
 
-  if ( size() == 1 )
+  if ( size() == 1 ) {
     return QByteArray::number( d->begin );
+  }
 
   QByteArray rv;
   rv += QByteArray::number( d->begin ) + ':';
 
-  if ( hasDefinedEnd() )
+  if ( hasDefinedEnd() ) {
     rv += QByteArray::number( d->end );
-  else
+  } else {
     rv += '*';
+  }
 
   return rv;
 }
 
-
 ImapSet::ImapSet()
   : d( new Private )
 {
@@ -179,10 +183,11 @@ ImapSet::~ImapSet()
 {
 }
 
-ImapSet& ImapSet::operator=( const ImapSet &other )
+ImapSet &ImapSet::operator=( const ImapSet &other )
 {
-  if ( this != &other )
+  if ( this != &other ) {
     d = other.d;
+  }
 
   return *this;
 }
@@ -206,7 +211,7 @@ void ImapSet::add( const QVector<Id> &values )
     do {
       ++i;
       Q_ASSERT( vals[i] >= 0 );
-      if ( vals[i] != (vals[i - 1] + 1) ) {
+      if ( vals[i] != ( vals[i - 1] + 1 ) ) {
         --i;
         break;
       }
@@ -223,8 +228,9 @@ void ImapSet::add( const ImapInterval &interval )
 QByteArray ImapSet::toImapSequenceSet() const
 {
   QList<QByteArray> rv;
-  Q_FOREACH ( const ImapInterval &interval, d->intervals )
+  Q_FOREACH ( const ImapInterval &interval, d->intervals ) {
     rv << interval.toImapSequence();
+  }
 
   return ImapParser::join( rv, "," );
 }
@@ -239,9 +245,14 @@ bool ImapSet::isEmpty() const
   return d->intervals.isEmpty();
 }
 
-QDebug& operator<<( QDebug &d, const Akonadi::ImapInterval &interval )
+QDebug &operator<<( QDebug &d, const Akonadi::ImapInterval &interval )
 {
   d << interval.toImapSequence();
   return d;
 }
 
+QDebug operator<<( QDebug d, const Akonadi::ImapSet &set )
+{
+  d << set.toImapSequenceSet();
+  return d;
+}
