@@ -24,11 +24,11 @@ using Akonadi::Tracer;
 
 #include <QtDBus>
 
-DebugInterface::DebugInterface(QObject * parent) :
-    QObject( parent )
+DebugInterface::DebugInterface( QObject *parent )
+  : QObject( parent )
 {
   new DebugInterfaceAdaptor( this );
-  QDBusConnection::sessionBus().registerObject( QLatin1String("/debug"),
+  QDBusConnection::sessionBus().registerObject( QLatin1String( "/debug" ),
     this, QDBusConnection::ExportAdaptors );
 }
 
@@ -37,9 +37,7 @@ QString DebugInterface::tracer() const
   return Tracer::self()->currentTracer();
 }
 
-void DebugInterface::setTracer(const QString & tracer)
+void DebugInterface::setTracer( const QString &tracer )
 {
   Tracer::self()->activateTracer( tracer );
 }
-
-#include "debuginterface.moc"
