@@ -45,7 +45,6 @@ Append::Append()
 {
 }
 
-
 Append::~Append()
 {
 }
@@ -70,8 +69,7 @@ bool Append::commit()
       while ( !m_streamParser->atLiteralEnd() ) {
         if ( !storeInFile ) {
           m_data += m_streamParser->readLiteralPart();
-        } else
-        {
+        } else {
           m_data = m_streamParser->readLiteralPart();
           tmpFile.write( m_data );
         }
@@ -90,14 +88,16 @@ bool Append::commit()
     Transaction transaction( db );
 
     Collection col = HandlerHelper::collectionFromIdOrName( m_mailbox );
-    if ( !col.isValid() )
+    if ( !col.isValid() ) {
       return failureResponse( QByteArray( "Unknown collection for '" ) + m_mailbox + QByteArray( "'." ) );
+    }
 
     QByteArray mt;
     QString remote_id;
     QString remote_revision;
+    QString gid;
     QList<QByteArray> flags;
-    Q_FOREACH( const QByteArray &flag, m_flags ) {
+    Q_FOREACH ( const QByteArray &flag, m_flags ) {
       if ( flag.startsWith( "\\MimeType" ) ) {
         int pos1 = flag.indexOf( '[' );
         int pos2 = flag.indexOf( ']', pos1 );
@@ -110,16 +110,24 @@ bool Append::commit()
         int pos1 = flag.indexOf( '[' );
         int pos2 = flag.lastIndexOf( ']' );
         remote_revision = QString::fromUtf8( flag.mid( pos1 + 1, pos2 - pos1 - 1 ) );
-      } else
+      } else if ( flag.startsWith( "\\Gid" ) ) {
+        int pos1 = flag.indexOf( '[' );
+        int pos2 = flag.lastIndexOf( ']' );
+        gid = QString::fromUtf8( flag.mid( pos1 + 1, pos2 - pos1 - 1 ) );
+      } else {
         flags << flag;
+      }
     }
     // standard imap does not know this attribute, so that's mail
-    if ( mt.isEmpty() ) mt = "message/rfc822";
+    if ( mt.isEmpty() ) {
+      mt = "message/rfc822";
+    }
     MimeType mimeType = MimeType::retrieveByName( QString::fromLatin1( mt ) );
     if ( !mimeType.isValid() ) {
       MimeType m( QString::fromLatin1( mt ) );
-      if ( !m.insert() )
-        return failureResponse( QByteArray( "Unable to create mimetype '") +  mt + QByteArray( "'." ) );
+      if ( !m.insert() ) {
+        return failureResponse( QByteArray( "Unable to create mimetype '" ) +  mt + QByteArray( "'." ) );
+      }
       mimeType = m;
     }
 
@@ -142,8 +150,7 @@ bool Append::commit()
     // for the UI and we enqueue the item for preprocessing.
     bool doPreprocessing = PreprocessorManager::instance()->isActive();
     //akDebug() << "Append handler: doPreprocessing is" << doPreprocessing;
-    if ( doPreprocessing )
-    {
+    if ( doPreprocessing ) {
       Part hiddenAttribute;
       hiddenAttribute.setName( QLatin1String( "ATR:HIDDEN" ) );
       hiddenAttribute.setData( QByteArray() );
@@ -152,7 +159,7 @@ bool Append::commit()
       parts.append( hiddenAttribute );
     }
 
-    bool ok = db->appendPimItem( parts, mimeType, col, m_dateTime, remote_id, remote_revision, item );
+    bool ok = db->appendPimItem( parts, mimeType, col, m_dateTime, remote_id, remote_revision, gid, item );
     response.setTag( tag() );
     if ( !ok ) {
         return failureResponse( "Append failed" );
@@ -161,17 +168,17 @@ bool Append::commit()
     // set message flags
     const Flag::List flagList = HandlerHelper::resolveFlags( flags );
     bool flagsChanged = false;
-    if ( !db->appendItemsFlags( PimItem::List() << item, flagList, flagsChanged, false, col ) )
+    if ( !db->appendItemsFlags( PimItem::List() << item, flagList, flagsChanged, false, col ) ) {
       return failureResponse( "Unable to append item flags." );
+    }
+
+    if ( storeInFile ) {
+      const QString fileName = PartHelper::resolveAbsolutePath( parts[0].data() );
 
-    if (storeInFile) {
       //the new item was just created and the transaction is not yet committed, so delete + overwrite should be safe, as no
       //client knows about the item yet
-      QString fileName = QString::fromUtf8( parts[0].data() );
-      QFile f( fileName );
-      if ( !f.remove() ) {
-        return failureResponse( "Unable to remove item part file" );
-      }
+      PartHelper::removeFile( fileName );
+
       if ( !tmpFile.copy( fileName ) ) {
         return failureResponse( "Unable to copy item part data from the temporary file" );
       }
@@ -181,11 +188,11 @@ bool Append::commit()
     //      actions SHOULD occur.  Specifically, the server SHOULD notify the
     //      client immediately via an untagged EXISTS response.
 
-    if ( !transaction.commit() )
+    if ( !transaction.commit() ) {
         return failureResponse( "Unable to commit transaction." );
+    }
 
-    if ( doPreprocessing )
-    {
+    if ( doPreprocessing ) {
       // enqueue the item for preprocessing
       PreprocessorManager::instance()->beginHandleItem( item, db );
     }
@@ -247,4 +254,3 @@ bool Append::parseStream()
 
   return commit();
 }
-
