@@ -36,18 +36,19 @@
 
 using namespace Akonadi;
 
-Delete::Delete( Scope scope ) :
-  Handler(),
-  m_scope( scope )
+Delete::Delete( Scope scope )
+  : Handler()
+  , m_scope( scope )
 {
 }
 
-bool Delete::deleteRecursive(Collection & col)
+bool Delete::deleteRecursive( Collection &col )
 {
   Collection::List children = col.children();
   Q_FOREACH ( Collection child, children ) {
-    if ( !deleteRecursive( child ) )
+    if ( !deleteRecursive( child ) ) {
       return false;
+    }
   }
   DataStore *db = connection()->storageBackend();
   return db->cleanupCollection( col );
@@ -58,37 +59,42 @@ bool Delete::parseStream()
   m_scope.parseScope( m_streamParser );
   SelectQueryBuilder<Collection> qb;
   CollectionQueryHelper::scopeToQuery( m_scope, connection(), qb );
-  if ( !qb.exec() )
+  if ( !qb.exec() ) {
     throw HandlerException( "Unable to execute collection query" );
+  }
   const Collection::List collections = qb.result();
-  if ( collections.isEmpty() )
+  if ( collections.isEmpty() ) {
     throw HandlerException( "No collection selected" );
-  else if ( collections.size() > 1 )
+  } else if ( collections.size() > 1 ) {
     throw HandlerException( "Deleting multiple collections is not yet implemented" );
-
+  }
 
   // check if collection exists
   DataStore *db = connection()->storageBackend();
   Transaction transaction( db );
 
   Collection collection = collections.first();
-  if ( !collection.isValid() )
+  if ( !collection.isValid() ) {
     return failureResponse( "No such collection." );
+  }
 
   // handle virtual folders
-  if ( collection.resource().name() == QLatin1String("akonadi_search_resource") ) {
+  if ( collection.resource().name() == QLatin1String( AKONADI_SEARCH_RESOURCE ) ) {
     // don't delete virtual root
-    if ( collection.parentId() == 0 )
+    if ( collection.parentId() == 0 ) {
       return failureResponse( "Cannot delete virtual root collection" );
+    }
 
     SearchManager::instance()->removeSearch( collection.id() );
   }
 
-  if ( !deleteRecursive( collection ) )
+  if ( !deleteRecursive( collection ) ) {
     return failureResponse( "Unable to delete collection" );
+  }
 
-  if ( !transaction.commit() )
+  if ( !transaction.commit() ) {
     return failureResponse( "Unable to commit transaction." );
+  }
 
   Response response;
   response.setTag( tag() );
@@ -96,4 +102,3 @@ bool Delete::parseStream()
   Q_EMIT responseAvailable( response );
   return true;
 }
-
