@@ -20,7 +20,6 @@
 #include "fetchhelper.h"
 
 #include "akdebug.h"
-#include "akonadi.h"
 #include "akonadiconnection.h"
 #include "handler.h"
 #include "handlerhelper.h"
@@ -29,7 +28,6 @@
 #include "libs/protocol_p.h"
 #include "response.h"
 #include "storage/selectquerybuilder.h"
-#include "resourceinterface.h"
 #include "storage/itemqueryhelper.h"
 #include "storage/itemretrievalmanager.h"
 #include "storage/itemretrievalrequest.h"
@@ -50,23 +48,24 @@
 using namespace Akonadi;
 
 FetchHelper::FetchHelper( AkonadiConnection *connection, const Scope &scope )
-  : mConnection( connection ), mScope( scope )
+  : mStreamParser( 0 )
+  , mConnection( connection )
+  , mScope( scope )
+  , mAncestorDepth( 0 )
+  , mCacheOnly( false )
+  , mCheckCachedPayloadPartsOnly( false )
+  , mFullPayload( false )
+  , mAllAttrs( false )
+  , mSizeRequested( false )
+  , mMTimeRequested( false )
+  , mExternalPayloadSupported( false )
+  , mRemoteRevisionRequested( false )
+  , mIgnoreErrors( false )
+  , mFlagsRequested( false )
+  , mRemoteIdRequested( false )
+  , mGidRequested( false )
 {
-  init();
-}
-
-void FetchHelper::init()
-{
-  mAncestorDepth = 0;
-  mCacheOnly = false;
-  mCheckCachedPayloadPartsOnly = false;
-  mFullPayload = false;
-  mAllAttrs = false;
-  mSizeRequested = false;
-  mMTimeRequested = false;
-  mExternalPayloadSupported = false;
-  mRemoteRevisionRequested = false;
-  mIgnoreErrors = false;
+  std::fill( mItemQueryColumnMap, mItemQueryColumnMap + ItemQueryColumnCount, -1 );
 }
 
 void FetchHelper::setStreamParser( ImapStreamParser *parser )
@@ -82,7 +81,7 @@ enum PartQueryColumns {
   PartQueryVersionColumn
 };
 
-QSqlQuery FetchHelper::buildPartQuery( const QStringList &partList, bool allPayload, bool allAttrs )
+QSqlQuery FetchHelper::buildPartQuery( const QVector<QByteArray> &partList, bool allPayload, bool allAttrs )
 {
   ///TODO: merge with ItemQuery
   QueryBuilder partQuery( PimItem::tableName() );
@@ -98,18 +97,26 @@ QSqlQuery FetchHelper::buildPartQuery( const QStringList &partList, bool allPayl
     partQuery.addSortColumn( PimItem::idFullColumnName(), Query::Descending );
 
     Query::Condition cond( Query::Or );
-    if ( !partList.isEmpty() )
-      cond.addValueCondition( Part::nameFullColumnName(), Query::In, partList );
-    if ( allPayload )
-      cond.addValueCondition( QString::fromLatin1( "substr( %1, 1, 4 )" ).arg( Part::nameFullColumnName() ), Query::Equals, QLatin1String( "PLD:" ) );
-    if ( allAttrs )
-      cond.addValueCondition( QString::fromLatin1( "substr( %1, 1, 4 )" ).arg( Part::nameFullColumnName() ), Query::Equals, QLatin1String( "ATR:" ) );
+    if ( !partList.isEmpty() ) {
+      QStringList partNameList;
+      partNameList.reserve( partList.size() );
+      Q_FOREACH ( const QByteArray &b, partList ) {
+        partNameList.push_back( QString::fromLatin1( b ) );
+      }
+      cond.addValueCondition( Part::nameFullColumnName(), Query::In, partNameList );
+    }
+    if ( allPayload ) {
+      cond.addValueCondition( QString::fromLatin1( "substr( %1, 1, 4 )" ).arg( Part::nameFullColumnName() ), Query::Equals, QLatin1String( AKONADI_PARAM_PLD ) );
+    }
+    if ( allAttrs ) {
+      cond.addValueCondition( QString::fromLatin1( "substr( %1, 1, 4 )" ).arg( Part::nameFullColumnName() ), Query::Equals, QLatin1String( AKONADI_PARAM_ATR ) );
+    }
     partQuery.addCondition( cond );
 
     ItemQueryHelper::scopeToQuery( mScope, mConnection, partQuery );
 
     if ( !partQuery.exec() ) {
-      throw HandlerException("Unable to list item parts");
+      throw HandlerException( "Unable to list item parts" );
     }
 
     partQuery.query().next();
@@ -118,51 +125,48 @@ QSqlQuery FetchHelper::buildPartQuery( const QStringList &partList, bool allPayl
   return partQuery.query();
 }
 
-enum ItemQueryColumns {
-  ItemQueryPimItemIdColumn,
-  ItemQueryPimItemRidColumn,
-  ItemQueryMimeTypeColumn,
-  ItemQueryResourceColumn,
-  ItemQueryRevColumn,
-  ItemQueryRemoteRevisionColumn,
-  ItemQuerySizeColumn,
-  ItemQueryDatetimeColumn,
-  ItemQueryCollectionIdColumn
-};
-
 QSqlQuery FetchHelper::buildItemQuery()
 {
   QueryBuilder itemQuery( PimItem::tableName() );
 
   itemQuery.addJoin( QueryBuilder::InnerJoin, MimeType::tableName(),
                      PimItem::mimeTypeIdFullColumnName(), MimeType::idFullColumnName() );
-  itemQuery.addJoin( QueryBuilder::InnerJoin, Collection::tableName(),
-                     PimItem::collectionIdFullColumnName(), Collection::idFullColumnName());
-  itemQuery.addJoin( QueryBuilder::InnerJoin, Resource::tableName(),
-                     Collection::resourceIdFullColumnName(), Resource::idFullColumnName() );
 
-  // make sure the columns indexes here and in the constants defined at the top of the file
-  itemQuery.addColumn( PimItem::idFullColumnName() );
-  itemQuery.addColumn( PimItem::remoteIdFullColumnName() );
-  itemQuery.addColumn( MimeType::nameFullColumnName() );
-  itemQuery.addColumn( Resource::nameFullColumnName() );
-  itemQuery.addColumn( PimItem::revFullColumnName() );
-  itemQuery.addColumn( PimItem::remoteRevisionFullColumnName() );
-  itemQuery.addColumn( PimItem::sizeFullColumnName() );
-  itemQuery.addColumn( PimItem::datetimeFullColumnName() );
-  itemQuery.addColumn( PimItem::collectionIdFullColumnName() );
+  int column = 0;
+  #define ADD_COLUMN(colName, colId) { itemQuery.addColumn( colName ); mItemQueryColumnMap[colId] = column++; }
+  ADD_COLUMN( PimItem::idFullColumnName(), ItemQueryPimItemIdColumn );
+  if ( mRemoteIdRequested ) {
+    ADD_COLUMN( PimItem::remoteIdFullColumnName(), ItemQueryPimItemRidColumn )
+  }
+  ADD_COLUMN( MimeType::nameFullColumnName(), ItemQueryMimeTypeColumn )
+  ADD_COLUMN( PimItem::revFullColumnName(), ItemQueryRevColumn )
+  if ( mRemoteRevisionRequested ) {
+    ADD_COLUMN( PimItem::remoteRevisionFullColumnName(), ItemQueryRemoteRevisionColumn )
+  }
+  if ( mSizeRequested ) {
+    ADD_COLUMN( PimItem::sizeFullColumnName(), ItemQuerySizeColumn )
+  }
+  if ( mMTimeRequested ) {
+    ADD_COLUMN( PimItem::datetimeFullColumnName(), ItemQueryDatetimeColumn )
+  }
+  ADD_COLUMN( PimItem::collectionIdFullColumnName(), ItemQueryCollectionIdColumn )
+  if ( mGidRequested ) {
+    ADD_COLUMN( PimItem::gidFullColumnName(), ItemQueryPimItemGidColumn )
+  }
+  #undef ADD_COLUMN
 
   itemQuery.addSortColumn( PimItem::idFullColumnName(), Query::Descending );
 
-  if ( mScope.scope() != Scope::Invalid )
+  if ( mScope.scope() != Scope::Invalid ) {
     ItemQueryHelper::scopeToQuery( mScope, mConnection, itemQuery );
+  }
 
   if ( mChangedSince.isValid() ) {
     itemQuery.addValueCondition( PimItem::datetimeFullColumnName(), Query::GreaterOrEqual, mChangedSince.toUTC() );
   }
 
   if ( !itemQuery.exec() ) {
-    throw HandlerException("Unable to list items");
+    throw HandlerException( "Unable to list items" );
   }
 
   itemQuery.query().next();
@@ -188,7 +192,7 @@ QSqlQuery FetchHelper::buildFlagQuery()
   flagQuery.addSortColumn( PimItem::idFullColumnName(), Query::Descending );
 
   if ( !flagQuery.exec() ) {
-    throw HandlerException("Unable to retrieve item flags");
+    throw HandlerException( "Unable to retrieve item flags" );
   }
 
   flagQuery.query().next();
@@ -202,45 +206,24 @@ bool FetchHelper::parseStream( const QByteArray &responseIdentifier )
   triggerOnDemandFetch();
 
   // retrieve missing parts
-  QStringList partList, payloadList;
-  Q_FOREACH( const QByteArray &b, mRequestedParts ) {
-    // filter out non-part attributes
-    if ( b == "REV" || b == "FLAGS" || b == "UID" || b == "REMOTEID" )
-      continue;
-    if ( b == "SIZE" ) {
-      mSizeRequested = true;
-      continue;
-    }
-    if ( b == "DATETIME" ) {
-      mMTimeRequested = true;
-      continue;
-    }
-    if ( b == "REMOTEREVISION" ) {
-      mRemoteRevisionRequested = true;
-      continue;
-    }
-    partList << QString::fromLatin1( b );
-    if ( b.startsWith( "PLD:" ) )
-      payloadList << QString::fromLatin1( b );
-  }
-
   if ( !mCacheOnly ) {
     // Prepare for a call to ItemRetriever::exec();
     // From a resource perspective the only parts that can be fetched are payloads.
     ItemRetriever retriever( mConnection );
     retriever.setScope( mScope );
-    retriever.setRetrieveParts( payloadList );
+    retriever.setRetrieveParts( mRequestedPayloads );
     retriever.setRetrieveFullPayload( mFullPayload );
     if ( !retriever.exec() && !mIgnoreErrors ) { // There we go, retrieve the missing parts from the resource.
-      if (mConnection->resourceContext().isValid())
-        throw HandlerException( QString::fromLatin1("Unable to fetch item from backend (collection %1, resource %2) : %3")
-                .arg(mConnection->selectedCollectionId())
-                .arg(mConnection->resourceContext().id())
-                .arg(QString::fromLatin1(retriever.lastError())));
-      else
-        throw HandlerException( QString::fromLatin1("Unable to fetch item from backend (collection %1) : %2")
-                .arg(mConnection->selectedCollectionId())
-                .arg(QString::fromLatin1(retriever.lastError())));
+      if ( mConnection->resourceContext().isValid() ) {
+        throw HandlerException( QString::fromLatin1( "Unable to fetch item from backend (collection %1, resource %2) : %3" )
+                .arg( mConnection->selectedCollectionId() )
+                .arg( mConnection->resourceContext().id() )
+                .arg( QString::fromLatin1( retriever.lastError() ) ) );
+      } else {
+        throw HandlerException( QString::fromLatin1( "Unable to fetch item from backend (collection %1) : %2" )
+                .arg( mConnection->selectedCollectionId() )
+                .arg( QString::fromLatin1( retriever.lastError() ) ) );
+      }
     }
   }
 
@@ -250,24 +233,25 @@ bool FetchHelper::parseStream( const QByteArray &responseIdentifier )
   // a request for a specific item
   if ( !itemQuery.isValid() ) {
     switch ( mScope.scope() ) {
-      case Scope::Uid: // fall through
-      case Scope::Rid: // fall through
-      case Scope::HierarchicalRid:
+    case Scope::Uid: // fall through
+    case Scope::Rid: // fall through
+    case Scope::HierarchicalRid: // fall through
+    case Scope::Gid:
         throw HandlerException( "Item query returned empty result set" );
-      break;
-      default:
+    break;
+    default:
         break;
     }
   }
   // build part query if needed
   QSqlQuery partQuery;
-  if ( !partList.isEmpty() || mFullPayload || mAllAttrs ) {
-    partQuery = buildPartQuery( partList, mFullPayload, mAllAttrs );
+  if ( !mRequestedParts.isEmpty() || mFullPayload || mAllAttrs ) {
+    partQuery = buildPartQuery( mRequestedParts, mFullPayload, mAllAttrs );
   }
 
   // build flag query if needed
   QSqlQuery flagQuery;
-  if ( mRequestedParts.contains( "FLAGS" ) ) {
+  if ( mFlagsRequested ) {
     flagQuery = buildFlagQuery();
   }
 
@@ -275,34 +259,43 @@ bool FetchHelper::parseStream( const QByteArray &responseIdentifier )
   Response response;
   response.setUntagged();
   while ( itemQuery.isValid() ) {
-    const qint64 pimItemId = itemQuery.value( ItemQueryPimItemIdColumn ).toLongLong();
-    const int pimItemRev = itemQuery.value( ItemQueryRevColumn ).toInt();
+    const qint64 pimItemId = extractQueryResult( itemQuery, ItemQueryPimItemIdColumn ).toLongLong();
+    const int pimItemRev = extractQueryResult( itemQuery, ItemQueryRevColumn ).toInt();
 
     QList<QByteArray> attributes;
-    attributes.append( "UID " + QByteArray::number( pimItemId ) );
-    attributes.append( "REV " + QByteArray::number( pimItemRev ) );
-    attributes.append( "REMOTEID " + ImapParser::quote( Utils::variantToByteArray( itemQuery.value( ItemQueryPimItemRidColumn ) ) ) );
-    attributes.append( "MIMETYPE " + ImapParser::quote( Utils::variantToByteArray( itemQuery.value( ItemQueryMimeTypeColumn ) ) ) );
-    Collection::Id parentCollectionId = itemQuery.value( ItemQueryCollectionIdColumn ).toLongLong();
-    attributes.append( "COLLECTIONID " + QByteArray::number( parentCollectionId ) );
+    attributes.append( AKONADI_PARAM_UID " " + QByteArray::number( pimItemId ) );
+    attributes.append( AKONADI_PARAM_REVISION " " + QByteArray::number( pimItemRev ) );
+    if ( mRemoteIdRequested ) {
+      attributes.append( AKONADI_PARAM_REMOTEID " " + ImapParser::quote( Utils::variantToByteArray( extractQueryResult( itemQuery, ItemQueryPimItemRidColumn ) ) ) );
+    }
+    attributes.append( AKONADI_PARAM_MIMETYPE " " + ImapParser::quote( Utils::variantToByteArray( extractQueryResult( itemQuery, ItemQueryMimeTypeColumn ) ) ) );
+    Collection::Id parentCollectionId = extractQueryResult( itemQuery, ItemQueryCollectionIdColumn ).toLongLong();
+    attributes.append( AKONADI_PARAM_COLLECTIONID " " + QByteArray::number( parentCollectionId ) );
 
     if ( mSizeRequested ) {
-      const qint64 pimItemSize = itemQuery.value( ItemQuerySizeColumn ).toLongLong();
-      attributes.append( "SIZE " + QByteArray::number( pimItemSize ) );
+      const qint64 pimItemSize = extractQueryResult( itemQuery, ItemQuerySizeColumn ).toLongLong();
+      attributes.append( AKONADI_PARAM_SIZE " " + QByteArray::number( pimItemSize ) );
     }
     if ( mMTimeRequested ) {
-      const QDateTime pimItemDatetime = itemQuery.value( ItemQueryDatetimeColumn ).toDateTime();
+      const QDateTime pimItemDatetime = extractQueryResult( itemQuery, ItemQueryDatetimeColumn ).toDateTime();
       // Date time is always stored in UTC time zone by the server.
       QString datetime = QLocale::c().toString( pimItemDatetime, QLatin1String( "dd-MMM-yyyy hh:mm:ss +0000" ) );
-      attributes.append( "DATETIME " + ImapParser::quote( datetime.toUtf8() ) );
+      attributes.append( AKONADI_PARAM_MTIME " " + ImapParser::quote( datetime.toUtf8() ) );
     }
     if ( mRemoteRevisionRequested ) {
-      const QByteArray rrev = Utils::variantToByteArray( itemQuery.value( ItemQueryRemoteRevisionColumn ) );
-      if ( !rrev.isEmpty() )
-        attributes.append( "REMOTEREVISION " + ImapParser::quote( rrev ) );
+      const QByteArray rrev = Utils::variantToByteArray( extractQueryResult( itemQuery, ItemQueryRemoteRevisionColumn ) );
+      if ( !rrev.isEmpty() ) {
+        attributes.append( AKONADI_PARAM_REMOTEREVISION " " + ImapParser::quote( rrev ) );
+      }
+    }
+    if ( mGidRequested ) {
+      const QByteArray gid = Utils::variantToByteArray( itemQuery.value( ItemQueryPimItemGidColumn ) );
+      if ( !gid.isEmpty() ) {
+        attributes.append( AKONADI_PARAM_GID " " + ImapParser::quote( gid ) );
+      }
     }
 
-    if ( mRequestedParts.contains( "FLAGS" ) ) {
+    if ( mFlagsRequested ) {
       QList<QByteArray> flags;
       while ( flagQuery.isValid() ) {
         const qint64 id = flagQuery.value( FlagQueryIdColumn ).toLongLong();
@@ -315,12 +308,12 @@ bool FetchHelper::parseStream( const QByteArray &responseIdentifier )
         flags << Utils::variantToByteArray( flagQuery.value( FlagQueryNameColumn ) );
         flagQuery.next();
       }
-      attributes.append( "FLAGS (" + ImapParser::join( flags, " " ) + ')' );
+      attributes.append( AKONADI_PARAM_FLAGS " (" + ImapParser::join( flags, " " ) + ')' );
     }
 
-    if ( mAncestorDepth > 0 )
+    if ( mAncestorDepth > 0 ) {
       attributes.append( HandlerHelper::ancestorsToByteArray( mAncestorDepth, ancestorsForItem( parentCollectionId ) ) );
-
+    }
 
     bool skipItem = false;
 
@@ -340,9 +333,9 @@ bool FetchHelper::parseStream( const QByteArray &responseIdentifier )
 
       if ( mCheckCachedPayloadPartsOnly ) {
         if ( !data.isEmpty() ) {
-           cachedParts << part;
+          cachedParts << part;
         }
-         partQuery.next();
+        partQuery.next();
      } else {
         if ( mIgnoreErrors && data.isEmpty() ) {
           //We wanted the payload, couldn't get it, and are ignoring errors. Skip the item.
@@ -351,8 +344,9 @@ bool FetchHelper::parseStream( const QByteArray &responseIdentifier )
           break;
         }
         bool partIsExternal = partQuery.value( PartQueryExternalColumn ).toBool();
-        if ( !mExternalPayloadSupported && partIsExternal ) //external payload not supported by the client, translate the data
+        if ( !mExternalPayloadSupported && partIsExternal ) { //external payload not supported by the client, translate the data
           data = PartHelper::translateData( data, partIsExternal );
+        }
         int version = partQuery.value( PartQueryVersionColumn ).toInt();
         if ( version != 0 ) { // '0' is the default, so don't send it
           part += '[' + QByteArray::number( version ) + ']';
@@ -365,27 +359,33 @@ bool FetchHelper::parseStream( const QByteArray &responseIdentifier )
         } else if ( data.isEmpty() ) {
           part += " \"\"";
         } else {
+          if ( partIsExternal ) {
+            if ( !mConnection->capabilities().noPayloadPath() ) {
+              data = PartHelper::resolveAbsolutePath( data ).toLocal8Bit();
+            }
+          }
+
           part += " {" + QByteArray::number( data.length() ) + "}\r\n";
           part += data;
         }
 
-        if ( mRequestedParts.contains( partName ) || mFullPayload || mAllAttrs )
+        if ( mRequestedParts.contains( partName ) || mFullPayload || mAllAttrs ) {
           attributes << part;
+        }
 
         partQuery.next();
       }
     }
 
-    if (skipItem) {
+    if ( skipItem ) {
       itemQuery.next();
       continue;
     }
 
     if ( mCheckCachedPayloadPartsOnly ) {
-      attributes.append( "CACHEDPARTS (" + ImapParser::join( cachedParts, " " ) + ')');
+      attributes.append( AKONADI_PARAM_CACHEDPARTS " (" + ImapParser::join( cachedParts, " " ) + ')' );
     }
 
-
     // IMAP protocol violation: should actually be the sequence number
     QByteArray attr = QByteArray::number( pimItemId ) + ' ' + responseIdentifier + " (";
     attr += ImapParser::join( attributes, " " ) + ')';
@@ -397,19 +397,20 @@ bool FetchHelper::parseStream( const QByteArray &responseIdentifier )
   }
 
   // update atime (only if the payload was actually requested, otherwise a simple resource sync prevents cache clearing)
-  if ( needsAccessTimeUpdate(partList) || mFullPayload )
+  if ( needsAccessTimeUpdate( mRequestedParts ) || mFullPayload ) {
     updateItemAccessTime();
+  }
 
   return true;
 }
 
-bool FetchHelper::needsAccessTimeUpdate(const QStringList& parts)
+bool FetchHelper::needsAccessTimeUpdate( const QVector<QByteArray> &parts )
 {
   // TODO technically we should compare the part list with the cache policy of
   // the parent collection of the retrieved items, but that's kinda expensive
   // Only updating the atime if the full payload was requested is a good
   // approximation though.
-  return parts.contains( QLatin1String("PLD:RFC822") );
+  return parts.contains( AKONADI_PARAM_PLD_RFC822 );
 }
 
 void FetchHelper::updateItemAccessTime()
@@ -419,40 +420,46 @@ void FetchHelper::updateItemAccessTime()
   qb.setColumnValue( PimItem::atimeColumn(), QDateTime::currentDateTime() );
   ItemQueryHelper::scopeToQuery( mScope, mConnection, qb );
 
-  if ( !qb.exec() )
+  if ( !qb.exec() ) {
     qWarning() << "Unable to update item access time";
-  else
+  } else {
     transaction.commit();
+  }
 }
 
 void FetchHelper::triggerOnDemandFetch()
 {
-  if ( mScope.scope() != Scope::None || mConnection->selectedCollectionId() <= 0 || mCacheOnly )
+  if ( mScope.scope() != Scope::None || mConnection->selectedCollectionId() <= 0 || mCacheOnly ) {
     return;
+  }
 
   Collection collection = mConnection->selectedCollection();
 
   // HACK: don't trigger on-demand syncing if the resource is the one triggering it
-  if ( mConnection->sessionId() == collection.resource().name().toLatin1() )
+  if ( mConnection->sessionId() == collection.resource().name().toLatin1() ) {
     return;
+  }
 
   DataStore *store = mConnection->storageBackend();
   store->activeCachePolicy( collection );
-  if ( !collection.cachePolicySyncOnDemand() )
+  if ( !collection.cachePolicySyncOnDemand() ) {
     return;
+  }
 
   IntervalCheck::instance()->requestCollectionSync( collection );
 }
 
 void FetchHelper::parseCommandStream()
 {
+  Q_ASSERT( mStreamParser );
+
   // macro vs. attribute list
   Q_FOREVER {
-    if ( mStreamParser->atCommandEnd() )
+    if ( mStreamParser->atCommandEnd() ) {
       break;
+    }
     if ( mStreamParser->hasList() ) {
-      QList<QByteArray> tmp = mStreamParser->readParenthesizedList();
-      mRequestedParts += tmp;
+      parsePartList();
       break;
     } else {
       const QByteArray buffer = mStreamParser->readString();
@@ -465,7 +472,7 @@ void FetchHelper::parseCommandStream()
       } else if ( buffer == AKONADI_PARAM_EXTERNALPAYLOAD ) {
         mExternalPayloadSupported = true;
       } else if ( buffer == AKONADI_PARAM_FULLPAYLOAD ) {
-        mRequestedParts << "PLD:RFC822"; // HACK: temporary workaround until we have support for detecting the availability of the full payload in the server
+        mRequestedParts << AKONADI_PARAM_PLD_RFC822; // HACK: temporary workaround until we have support for detecting the availability of the full payload in the server
         mFullPayload = true;
       } else if ( buffer == AKONADI_PARAM_ANCESTORS ) {
         mAncestorDepth = HandlerHelper::parseDepth( mStreamParser->readString() );
@@ -484,21 +491,59 @@ void FetchHelper::parseCommandStream()
   }
 }
 
+void FetchHelper::parsePartList()
+{
+  mStreamParser->beginList();
+  while ( !mStreamParser->atListEnd() ) {
+    const QByteArray b = mStreamParser->readString();
+    // filter out non-part attributes we send all the time
+    if ( b == AKONADI_PARAM_REVISION || b == AKONADI_PARAM_UID ) {
+      continue;
+    } else if ( b == AKONADI_PARAM_REMOTEID ) {
+      mRemoteIdRequested = true;
+    } else if ( b == AKONADI_PARAM_FLAGS ) {
+      mFlagsRequested = true;
+    } else if ( b == AKONADI_PARAM_SIZE ) {
+      mSizeRequested = true;
+    } else if ( b == AKONADI_PARAM_MTIME ) {
+      mMTimeRequested = true;
+    } else if ( b == AKONADI_PARAM_REMOTEREVISION ) {
+      mRemoteRevisionRequested = true;
+    } else if ( b == AKONADI_PARAM_GID ) {
+      mGidRequested = true;
+    } else {
+      mRequestedParts.push_back( b );
+      if ( b.startsWith( AKONADI_PARAM_PLD ) ) {
+        mRequestedPayloads.push_back( QString::fromLatin1( b ) );
+      }
+    }
+  }
+}
+
 QStack<Collection> FetchHelper::ancestorsForItem( Collection::Id parentColId )
 {
-  if ( mAncestorDepth <= 0 || parentColId == 0 )
+  if ( mAncestorDepth <= 0 || parentColId == 0 ) {
     return QStack<Collection>();
-  if ( mAncestorCache.contains( parentColId ) )
+  }
+  if ( mAncestorCache.contains( parentColId ) ) {
     return mAncestorCache.value( parentColId );
+  }
 
   QStack<Collection> ancestors;
   Collection col = Collection::retrieveById( parentColId );
   for ( int i = 0; i < mAncestorDepth; ++i ) {
-    if ( !col.isValid() )
+    if ( !col.isValid() ) {
       break;
+    }
     ancestors.prepend( col );
     col = col.parent();
   }
   mAncestorCache.insert( parentColId, ancestors );
   return ancestors;
 }
+
+QVariant FetchHelper::extractQueryResult( const QSqlQuery &query, FetchHelper::ItemQueryColumns column ) const
+{
+  Q_ASSERT( mItemQueryColumnMap[column] >= 0 );
+  return query.value( mItemQueryColumnMap[column] );
+}
