@@ -32,8 +32,8 @@
 
 namespace Akonadi {
 
-Move::Move( Scope::SelectionScope scope ) :
-  mScope( scope )
+Move::Move( Scope::SelectionScope scope )
+  : mScope( scope )
 {
 }
 
@@ -50,7 +50,7 @@ bool Move::parseStream()
   ItemRetriever retriever( connection() );
   retriever.setScope( mScope );
   retriever.setRetrieveFullPayload( true );
-  if (!retriever.exec()) {
+  if ( !retriever.exec() ) {
     return failureResponse( retriever.lastError() );
   }
 
@@ -65,30 +65,34 @@ bool Move::parseStream()
 
   if ( qb.exec() ) {
     const QVector<PimItem> items = qb.result();
-    if ( items.isEmpty() )
+    if ( items.isEmpty() ) {
       throw HandlerException( "No items found" );
+    }
 
     // Split the list by source collection
     QMap<Entity::Id /* collection */, PimItem> toMove;
     QMap<Entity::Id /* collection */, Collection> sources;
     Q_FOREACH ( /*sic!*/ PimItem item, items ) {
       const Collection source = items.first().collection();
-      if ( !source.isValid() )
+      if ( !source.isValid() ) {
         throw HandlerException( "Item without collection found!?" );
+      }
       if ( !sources.contains( source.id() ) ) {
         sources.insert( source.id(), source );
       }
 
-      if ( !item.isValid() )
+      if ( !item.isValid() ) {
         throw HandlerException( "Invalid item in result set!?" );
+      }
       Q_ASSERT( item.collectionId() != destination.id() );
 
       item.setCollectionId( destination.id() );
       item.setAtime( mtime );
       item.setDatetime( mtime );
       // if the resource moved itself, we assume it did so because the change happend in the backend
-      if ( connection()->resourceContext().id() != destResource.id() )
+      if ( connection()->resourceContext().id() != destResource.id() ) {
         item.setDirty( true );
+      }
 
       toMove.insertMulti( source.id(), item );
     }
@@ -103,8 +107,9 @@ bool Move::parseStream()
         // reset RID on inter-resource moves, but only after generating the change notification
         // so that this still contains the old one for the source resource
         const bool isInterResourceMove = moved.collection().resource().id() != destResource.id();
-        if ( isInterResourceMove )
+        if ( isInterResourceMove ) {
           moved.setRemoteId( QString() );
+        }
 
         // FIXME Could we aggregate the changes to a single SQL query?
         if ( !moved.update() ) {
@@ -116,11 +121,11 @@ bool Move::parseStream()
     throw HandlerException( "Unable to execute query" );
   }
 
-  if ( !transaction.commit() )
+  if ( !transaction.commit() ) {
     return failureResponse( "Unable to commit transaction." );
+  }
 
   return successResponse( "MOVE complete" );
 }
 
 }
-
