@@ -33,13 +33,13 @@ class ImapStreamParser;
 class Scope
 {
   public:
-    enum SelectionScope
-    {
+    enum SelectionScope {
       Invalid,
       None,
       Uid,
       Rid,
-      HierarchicalRid
+      HierarchicalRid,
+      Gid
     };
 
     Scope( SelectionScope scope );
@@ -61,12 +61,14 @@ class Scope
     void setUidSet( const ImapSet &uidSet );
     QStringList ridSet() const;
     QStringList ridChain() const;
+    QStringList gidSet() const;
 
   private:
     SelectionScope mScope;
     ImapSet mUidSet;
     QStringList mRidSet;
     QStringList mRidChain;
+    QStringList mGidSet;
 };
 
 }
