@@ -30,37 +30,41 @@
 
 using namespace Akonadi;
 
-Collection HandlerHelper::collectionFromIdOrName(const QByteArray & id)
+Collection HandlerHelper::collectionFromIdOrName( const QByteArray &id )
 {
   // id is a number
   bool ok = false;
   qint64 collectionId = id.toLongLong( &ok );
-  if ( ok )
+  if ( ok ) {
     return Collection::retrieveById( collectionId );
+  }
 
   // id is a path
   QString path = QString::fromUtf8( id ); // ### should be UTF-7 for real IMAP compatibility
 
-  const QStringList pathParts = path.split( QLatin1Char('/'), QString::SkipEmptyParts );
+  const QStringList pathParts = path.split( QLatin1Char( '/' ), QString::SkipEmptyParts );
   Collection col;
   Q_FOREACH ( const QString &part, pathParts ) {
     SelectQueryBuilder<Collection> qb;
     qb.addValueCondition( Collection::nameColumn(), Query::Equals, part );
-    if ( col.isValid() )
+    if ( col.isValid() ) {
       qb.addValueCondition( Collection::parentIdColumn(), Query::Equals, col.id() );
-    else
+    } else {
       qb.addValueCondition( Collection::parentIdColumn(), Query::Is, QVariant() );
-    if ( !qb.exec() )
+    }
+    if ( !qb.exec() ) {
       return Collection();
+    }
     Collection::List list = qb.result();
-    if ( list.count() != 1 )
+    if ( list.count() != 1 ) {
       return Collection();
+    }
     col = list.first();
   }
   return col;
 }
 
-QString HandlerHelper::pathForCollection(const Collection & col)
+QString HandlerHelper::pathForCollection( const Collection &col )
 {
   QStringList parts;
   Collection current = col;
@@ -68,14 +72,14 @@ QString HandlerHelper::pathForCollection(const Collection & col)
     parts.prepend( current.name() );
     current = current.parent();
   }
-  return parts.join( QLatin1String("/") );
+  return parts.join( QLatin1String( "/" ) );
 }
 
-bool HandlerHelper::itemStatistics(const Akonadi::Collection& col, qint64& count, qint64& size)
+bool HandlerHelper::itemStatistics( const Akonadi::Collection &col, qint64 &count, qint64 &size )
 {
   QueryBuilder qb( PimItem::tableName() );
-  qb.addAggregation( PimItem::idColumn(), QLatin1String("count") );
-  qb.addAggregation( PimItem::sizeColumn(), QLatin1String("sum") );
+  qb.addAggregation( PimItem::idColumn(), QLatin1String( "count" ) );
+  qb.addAggregation( PimItem::sizeColumn(), QLatin1String( "sum" ) );
 
   if ( col.resource().isVirtual() ) {
     qb.addJoin( QueryBuilder::InnerJoin, CollectionPimItemRelation::tableName(),
@@ -85,8 +89,9 @@ bool HandlerHelper::itemStatistics(const Akonadi::Collection& col, qint64& count
     qb.addValueCondition( PimItem::collectionIdColumn(), Query::Equals, col.id() );
   }
 
-  if ( !qb.exec() )
+  if ( !qb.exec() ) {
     return false;
+  }
   if ( !qb.query().next() ) {
     akError() << "Error during retrieving result of statistics query:" << qb.query().lastError().text();
     return false;
@@ -96,7 +101,7 @@ bool HandlerHelper::itemStatistics(const Akonadi::Collection& col, qint64& count
   return true;
 }
 
-int HandlerHelper::itemWithFlagsCount(const Akonadi::Collection& col, const QStringList& flags)
+int HandlerHelper::itemWithFlagsCount( const Akonadi::Collection &col, const QStringList &flags )
 {
   CountQueryBuilder qb( PimItem::tableName(), PimItem::idFullColumnName(), CountQueryBuilder::Distinct );
   qb.addJoin( QueryBuilder::InnerJoin, PimItemFlagRelation::tableName(),
@@ -118,21 +123,23 @@ int HandlerHelper::itemWithFlagsCount(const Akonadi::Collection& col, const QStr
     cond.addValueCondition( PimItemFlagRelation::rightFullColumnName(), Query::Equals, f.id() );
   }
   qb.addCondition( cond );
-  if ( !qb.exec() )
+  if ( !qb.exec() ) {
     return -1;
+  }
   return qb.result();
 }
 
-int HandlerHelper::itemCount(const Collection& col)
+int HandlerHelper::itemCount( const Collection &col )
 {
   CountQueryBuilder qb( PimItem::tableName() );
   qb.addValueCondition( PimItem::collectionIdColumn(), Query::Equals, col.id() );
-  if ( !qb.exec() )
+  if ( !qb.exec() ) {
     return -1;
+  }
   return qb.result();
 }
 
-int HandlerHelper::parseCachePolicy(const QByteArray & data, Collection & col, int start, bool *changed )
+int HandlerHelper::parseCachePolicy( const QByteArray &data, Collection &col, int start, bool *changed )
 {
   bool inheritChanged = false;
   bool somethingElseChanged = false;
@@ -143,75 +150,80 @@ int HandlerHelper::parseCachePolicy(const QByteArray & data, Collection & col, i
     const QByteArray key = params[i];
     const QByteArray value = params[i + 1];
 
-    if ( key == "INHERIT" ) {
+    if ( key == AKONADI_PARAM_INHERIT ) {
       const bool inherit = value == "true";
       inheritChanged = col.cachePolicyInherit() != inherit;
       col.setCachePolicyInherit( inherit );
-    } else if ( key == "INTERVAL" ) {
+    } else if ( key == AKONADI_PARAM_INTERVAL ) {
       const int interval = value.toInt();
       somethingElseChanged = somethingElseChanged || interval != col.cachePolicyCheckInterval();
       col.setCachePolicyCheckInterval( interval );
-    } else if ( key == "CACHETIMEOUT" ) {
+    } else if ( key == AKONADI_PARAM_CACHETIMEOUT ) {
       const int timeout = value.toInt();
       somethingElseChanged = somethingElseChanged || timeout != col.cachePolicyCacheTimeout();
       col.setCachePolicyCacheTimeout( timeout );
-    } else if ( key == "SYNCONDEMAND" ) {
+    } else if ( key == AKONADI_PARAM_SYNCONDEMAND ) {
       const bool syncOnDemand = value == "true";
       somethingElseChanged = somethingElseChanged || syncOnDemand != col.cachePolicySyncOnDemand();
       col.setCachePolicySyncOnDemand( syncOnDemand );
-    } else if ( key == "LOCALPARTS" ) {
+    } else if ( key == AKONADI_PARAM_LOCALPARTS ) {
       QList<QByteArray> tmp;
       QStringList partsList;
       Akonadi::ImapParser::parseParenthesizedList( value, tmp );
-      Q_FOREACH ( const QByteArray &ba, tmp )
+      Q_FOREACH ( const QByteArray &ba, tmp ) {
         partsList << QString::fromLatin1( ba );
+      }
       const QString parts = partsList.join( QLatin1String( " " ) );
       somethingElseChanged = somethingElseChanged || col.cachePolicyLocalParts() != parts;
       col.setCachePolicyLocalParts( parts );
     }
   }
 
-  if ( changed && (inheritChanged || (!col.cachePolicyInherit() && somethingElseChanged)) )
+  if ( changed && ( inheritChanged || ( !col.cachePolicyInherit() && somethingElseChanged ) ) ) {
     *changed = true;
+  }
 
   return end;
 }
 
-QByteArray HandlerHelper::cachePolicyToByteArray(const Collection & col)
+QByteArray HandlerHelper::cachePolicyToByteArray( const Collection &col )
 {
-  QByteArray rv = "CACHEPOLICY (";
-  rv += "INHERIT " + ( col.cachePolicyInherit() ? QByteArray("true") : QByteArray("false") );
-  rv += " INTERVAL " + QByteArray::number( col.cachePolicyCheckInterval() );
-  rv += " CACHETIMEOUT " + QByteArray::number( col.cachePolicyCacheTimeout() );
-  rv += " SYNCONDEMAND " + ( col.cachePolicySyncOnDemand() ? QByteArray("true") : QByteArray("false") );
-  rv += " LOCALPARTS (" + col.cachePolicyLocalParts().toLatin1() + ')';
+  QByteArray rv = AKONADI_PARAM_CACHEPOLICY " (";
+  rv += AKONADI_PARAM_INHERIT " " + ( col.cachePolicyInherit() ? QByteArray( "true" ) : QByteArray( "false" ) );
+  rv += " " AKONADI_PARAM_INTERVAL " " + QByteArray::number( col.cachePolicyCheckInterval() );
+  rv += " " AKONADI_PARAM_CACHETIMEOUT " " + QByteArray::number( col.cachePolicyCacheTimeout() );
+  rv += " " AKONADI_PARAM_SYNCONDEMAND " " + ( col.cachePolicySyncOnDemand() ? QByteArray( "true" ) : QByteArray( "false" ) );
+  rv += " " AKONADI_PARAM_LOCALPARTS " (" + col.cachePolicyLocalParts().toLatin1() + ')';
   rv += ')';
   return rv;
 }
 
-QByteArray HandlerHelper::collectionToByteArray( const Collection & col, bool hidden, bool includeStatistics,
+QByteArray HandlerHelper::collectionToByteArray( const Collection &col, bool hidden, bool includeStatistics,
                                                  int ancestorDepth, const QStack<Collection> &ancestors )
 {
   QByteArray b = QByteArray::number( col.id() ) + ' '
                + QByteArray::number( col.parentId() ) + " (";
 
-  b += "NAME "+ ImapParser::quote( col.name().toUtf8() ) + ' ';
-  if ( hidden )
-    b+= "MIMETYPE () ";
-  else
-    b += "MIMETYPE (" + MimeType::joinByName( col.mimeTypes(), QLatin1String( " " ) ).toLatin1() + ") ";
-  b += "REMOTEID " + ImapParser::quote( col.remoteId().toUtf8() );
-  b += " REMOTEREVISION " + ImapParser::quote( col.remoteRevision().toUtf8() );
-  b += " RESOURCE " + ImapParser::quote( col.resource().name().toUtf8() );
-  b += " VIRTUAL " + QByteArray::number( col.isVirtual() ) + ' ';
+  b += AKONADI_PARAM_NAME " " + ImapParser::quote( col.name().toUtf8() ) + ' ';
+  if ( hidden ) {
+    b += AKONADI_PARAM_MIMETYPE " () ";
+  } else {
+    b += AKONADI_PARAM_MIMETYPE " (" + MimeType::joinByName( col.mimeTypes(), QLatin1String( " " ) ).toLatin1() + ") ";
+  }
+  b += AKONADI_PARAM_REMOTEID " " + ImapParser::quote( col.remoteId().toUtf8() );
+  b += " " AKONADI_PARAM_REMOTEREVISION " " + ImapParser::quote( col.remoteRevision().toUtf8() );
+  b += " " AKONADI_PARAM_RESOURCE " " + ImapParser::quote( col.resource().name().toUtf8() );
+  b += " " AKONADI_PARAM_VIRTUAL " " + QByteArray::number( col.isVirtual() ) + ' ';
 
   if ( includeStatistics ) {
     qint64 itemCount, itemSize;
     if ( itemStatistics( col, itemCount, itemSize ) ) {
-      b += "MESSAGES " + QByteArray::number( itemCount ) + ' ';
+      b += AKONADI_ATTRIBUTE_MESSAGES " " + QByteArray::number( itemCount ) + ' ';
       // itemWithFlagCount is twice as fast as itemWithoutFlagCount, so emulated that...
-      b += "UNSEEN " + QByteArray::number( itemCount - itemWithFlagsCount( col, QStringList() << QLatin1String( "\\SEEN" ) << QLatin1String( "$IGNORED" ) ) ) + ' ';
-      b += "SIZE " + QByteArray::number( itemSize ) + ' ';
+      b += AKONADI_ATTRIBUTE_UNSEEN " ";
+      b += QByteArray::number( itemCount - itemWithFlagsCount( col, QStringList() << QLatin1String( AKONADI_FLAG_SEEN )
+                                                                                  << QLatin1String( AKONADI_FLAG_IGNORED ) ) );
+      b += " " AKONADI_PARAM_SIZE " " + QByteArray::number( itemSize ) + ' ';
     }
   }
 
@@ -227,15 +239,17 @@ QByteArray HandlerHelper::collectionToByteArray( const Collection & col, bool hi
   }
 
   b += HandlerHelper::cachePolicyToByteArray( col ) + ' ';
-  if ( ancestorDepth > 0 )
+  if ( ancestorDepth > 0 ) {
     b += HandlerHelper::ancestorsToByteArray( ancestorDepth, ancestors ) + ' ';
+  }
 
   const CollectionAttribute::List attrs = col.attributes();
   for ( int i = 0; i < attrs.size(); ++i ) {
     const CollectionAttribute &attr = attrs[i];
     b += attr.type() + ' ' + ImapParser::quote( attr.value() );
-    if ( i != attrs.size() - 1 )
+    if ( i != attrs.size() - 1 ) {
       b += ' ';
+    }
   }
   b+= ')';
 
@@ -258,8 +272,9 @@ QByteArray HandlerHelper::ancestorsToByteArray( int ancestorDepth, const QStack<
       b += QByteArray::number( c.id() ) + " ";
       b += ImapParser::quote( c.remoteId().toUtf8() );
       b += ")";
-      if ( i != ancestorDepth - 1 )
+      if ( i != ancestorDepth - 1 ) {
         b += ' ';
+      }
     }
     b += ')';
   }
@@ -268,26 +283,30 @@ QByteArray HandlerHelper::ancestorsToByteArray( int ancestorDepth, const QStack<
 
 int HandlerHelper::parseDepth( const QByteArray &depth )
 {
-  if ( depth.isEmpty() )
+  if ( depth.isEmpty() ) {
     throw ImapParserException( "No depth specified" );
-  if ( depth == "INF" )
+  }
+  if ( depth == "INF" ) {
     return INT_MAX;
+  }
   bool ok = false;
   int result = depth.toInt( &ok );
-  if ( !ok )
+  if ( !ok ) {
     throw ImapParserException( "Invalid depth argument" );
+  }
   return result;
 }
 
-Akonadi::Flag::List Akonadi::HandlerHelper::resolveFlags(const QList< QByteArray >& flagNames)
+Akonadi::Flag::List Akonadi::HandlerHelper::resolveFlags( const QList< QByteArray > &flagNames )
 {
   Flag::List flagList;
   Q_FOREACH ( const QByteArray &flagName, flagNames ) {
     Flag flag = Flag::retrieveByName( QString::fromUtf8( flagName ) );
     if ( !flag.isValid() ) {
       flag = Flag( QString::fromUtf8( flagName ) );
-      if ( !flag.insert() )
+      if ( !flag.insert() ) {
         throw HandlerException( "Unable to create flag" );
+      }
     }
     flagList.append( flag );
   }
