@@ -33,25 +33,26 @@
 
 using namespace Akonadi;
 
-DbIntrospector::Ptr DbIntrospector::createInstance(const QSqlDatabase& database)
+DbIntrospector::Ptr DbIntrospector::createInstance( const QSqlDatabase &database )
 {
   switch ( DbType::type( database ) ) {
-    case DbType::MySQL:
-      return Ptr( new DbIntrospectorMySql( database ) );
-    case DbType::Sqlite:
-      return Ptr( new DbIntrospectorSqlite( database ) );
-    case DbType::PostgreSQL:
-      return Ptr( new DbIntrospectorPostgreSql( database ) );
-    case DbType::Virtuoso:
-      return Ptr( new DbIntrospectorVirtuoso( database ) );
-    case DbType::Unknown:
-      break;
+  case DbType::MySQL:
+    return Ptr( new DbIntrospectorMySql( database ) );
+  case DbType::Sqlite:
+    return Ptr( new DbIntrospectorSqlite( database ) );
+  case DbType::PostgreSQL:
+    return Ptr( new DbIntrospectorPostgreSql( database ) );
+  case DbType::Virtuoso:
+    return Ptr( new DbIntrospectorVirtuoso( database ) );
+  case DbType::Unknown:
+    break;
   }
   akFatal() << database.driverName() << "backend  not supported";
   return Ptr();
 }
 
-DbIntrospector::DbIntrospector(const QSqlDatabase& database) : m_database( database )
+DbIntrospector::DbIntrospector( const QSqlDatabase &database )
+  : m_database( database )
 {
 }
 
@@ -59,20 +60,21 @@ DbIntrospector::~DbIntrospector()
 {
 }
 
-bool DbIntrospector::hasTable(const QString& tableName)
+bool DbIntrospector::hasTable( const QString &tableName )
 {
   return m_database.tables().contains( tableName, Qt::CaseInsensitive );
 }
 
-bool DbIntrospector::hasIndex(const QString& tableName, const QString& indexName)
+bool DbIntrospector::hasIndex( const QString &tableName, const QString &indexName )
 {
   QSqlQuery query( m_database );
-  if ( !query.exec( hasIndexQuery( tableName, indexName ) ) )
+  if ( !query.exec( hasIndexQuery( tableName, indexName ) ) ) {
     throw DbException( query, "Failed to query index" );
+  }
   return query.next();
 }
 
-bool DbIntrospector::hasColumn(const QString& tableName, const QString& columnName)
+bool DbIntrospector::hasColumn( const QString &tableName, const QString &columnName )
 {
   QStringList columns = m_columnCache.value( tableName );
 
@@ -89,27 +91,29 @@ bool DbIntrospector::hasColumn(const QString& tableName, const QString& columnNa
   return columns.contains( columnName.toLower() );
 }
 
-bool DbIntrospector::isTableEmpty(const QString& tableName)
+bool DbIntrospector::isTableEmpty( const QString &tableName )
 {
   QueryBuilder queryBuilder( tableName, QueryBuilder::Select );
   queryBuilder.addColumn( QLatin1String( "*" ) );
   queryBuilder.setLimit( 1 );
-  if ( !queryBuilder.exec() )
+  if ( !queryBuilder.exec() ) {
     throw DbException( queryBuilder.query(), "Unable to retrieve data from table." );
+  }
 
   QSqlQuery query = queryBuilder.query();
-  if ( query.size() == 0  || !query.first() ) // table is empty
+  if ( query.size() == 0  || !query.first() ) { // table is empty
     return true;
+  }
   return false;
 }
 
-QVector<DbIntrospector::ForeignKey> DbIntrospector::foreignKeyConstraints( const QString& tableName )
+QVector<DbIntrospector::ForeignKey> DbIntrospector::foreignKeyConstraints( const QString &tableName )
 {
   Q_UNUSED( tableName );
   return QVector<ForeignKey>();
 }
 
-QString DbIntrospector::hasIndexQuery(const QString& tableName, const QString& indexName)
+QString DbIntrospector::hasIndexQuery( const QString &tableName, const QString &indexName )
 {
   Q_UNUSED( tableName );
   Q_UNUSED( indexName );
