@@ -32,9 +32,9 @@
 #include <QDomDocument>
 #include <QFile>
 
-DbUpdater::DbUpdater( const QSqlDatabase & database, const QString & filename )
-  : m_database( database ),
-    m_filename( filename )
+DbUpdater::DbUpdater( const QSqlDatabase &database, const QString &filename )
+  : m_database( database )
+  , m_filename( filename )
 {
 }
 
@@ -47,14 +47,16 @@ bool DbUpdater::run()
 
   UpdateSet::Map updates;
 
-  if ( !parseUpdateSets( currentVersion.version(), updates ) )
+  if ( !parseUpdateSets( currentVersion.version(), updates ) ) {
     return false;
+  }
 
-  if ( updates.isEmpty() )
+  if ( updates.isEmpty() ) {
     return true;
+  }
   // indicate clients this might take a while
   // we can ignore unregistration in error cases, that'll kill the server anyway
-  QDBusConnection::sessionBus().registerService( AkDBus::serviceName(AkDBus::UpgradeIndicator) );
+  QDBusConnection::sessionBus().registerService( AkDBus::serviceName( AkDBus::UpgradeIndicator ) );
 
   // QMap is sorted, so we should be replaying the changes in correct order
   for ( QMap<int, UpdateSet>::ConstIterator it = updates.constBegin(); it != updates.constEnd(); ++it ) {
@@ -82,12 +84,13 @@ bool DbUpdater::run()
     if ( !success || !m_database.commit() ) {
       akError() << "Failed to commit transaction for database update";
       m_database.rollback();
-      if ( it.value().abortOnFailure )
+      if ( it.value().abortOnFailure ) {
         return false;
+      }
     }
   }
 
-  QDBusConnection::sessionBus().unregisterService( AkDBus::serviceName(AkDBus::UpgradeIndicator) );
+  QDBusConnection::sessionBus().unregisterService( AkDBus::serviceName( AkDBus::UpgradeIndicator ) );
   return true;
 }
 
@@ -105,7 +108,7 @@ bool DbUpdater::parseUpdateSets( int currentVersion, UpdateSet::Map &updates ) c
   int line, column;
   if ( !document.setContent( &file, &errorMsg, &line, &column ) ) {
     akError() << "Unable to parse update description file" << m_filename << ":"
-        << errorMsg << "at line" << line << "column" << column;
+              << errorMsg << "at line" << line << "column" << column;
     return false;
   }
 
@@ -135,7 +138,7 @@ bool DbUpdater::parseUpdateSets( int currentVersion, UpdateSet::Map &updates ) c
       } else {
         UpdateSet updateSet;
         updateSet.version = version;
-        updateSet.abortOnFailure = (updateElement.attribute( QLatin1String( "abortOnFailure" ) ) == QLatin1String( "true" ));
+        updateSet.abortOnFailure = ( updateElement.attribute( QLatin1String( "abortOnFailure" ) ) == QLatin1String( "true" ) );
 
         QDomElement childElement = updateElement.firstChildElement();
         while ( !childElement.isNull() ) {
@@ -164,16 +167,20 @@ bool DbUpdater::updateApplicable( const QString &backends ) const
 
   QString currentBackend;
   switch ( DbType::type( m_database ) ) {
-    case DbType::MySQL:
-      currentBackend = QLatin1String( "mysql" ); break;
-    case DbType::PostgreSQL:
-      currentBackend = QLatin1String( "psql" ); break;
-    case DbType::Sqlite:
-      currentBackend = QLatin1String( "sqlite" ); break;
-    case DbType::Virtuoso:
-      currentBackend = QLatin1String( "odbc" ); break;
-    case DbType::Unknown:
-      return false;
+  case DbType::MySQL:
+    currentBackend = QLatin1String( "mysql" );
+    break;
+  case DbType::PostgreSQL:
+    currentBackend = QLatin1String( "psql" );
+    break;
+  case DbType::Sqlite:
+    currentBackend = QLatin1String( "sqlite" );
+    break;
+  case DbType::Virtuoso:
+    currentBackend = QLatin1String( "odbc" );
+    break;
+  case DbType::Unknown:
+    return false;
   }
 
   return matchingBackends.contains( currentBackend );
