@@ -23,6 +23,7 @@
 #ifndef QUERYBUILDER_UNITTEST
 #include "storage/datastore.h"
 #include "storage/querycache.h"
+#include "storage/storagedebugger.h"
 #endif
 
 #include <QSqlRecord>
@@ -33,26 +34,26 @@ using namespace Akonadi;
 static QString compareOperatorToString( Query::CompareOperator op )
 {
   switch ( op ) {
-    case Query::Equals:
-      return QLatin1String( " = " );
-    case Query::NotEquals:
-      return QLatin1String( " <> " );
-    case Query::Is:
-      return QLatin1String( " IS " );
-    case Query::IsNot:
-      return QLatin1String( " IS NOT " );
-    case Query::Less:
-      return QLatin1String( " < " );
-    case Query::LessOrEqual:
-      return QLatin1String( " <= " );
-    case Query::Greater:
-      return QLatin1String( " > " );
-    case Query::GreaterOrEqual:
-      return QLatin1String( " >= " );
-    case Query::In:
-      return QLatin1String( " IN " );
-    case Query::NotIn:
-      return QLatin1String( " NOT IN " );
+  case Query::Equals:
+    return QLatin1String( " = " );
+  case Query::NotEquals:
+    return QLatin1String( " <> " );
+  case Query::Is:
+    return QLatin1String( " IS " );
+  case Query::IsNot:
+    return QLatin1String( " IS NOT " );
+  case Query::Less:
+    return QLatin1String( " < " );
+  case Query::LessOrEqual:
+    return QLatin1String( " <= " );
+  case Query::Greater:
+    return QLatin1String( " > " );
+  case Query::GreaterOrEqual:
+    return QLatin1String( " >= " );
+  case Query::In:
+    return QLatin1String( " IN " );
+  case Query::NotIn:
+    return QLatin1String( " NOT IN " );
   }
   Q_ASSERT_X( false, "QueryBuilder::compareOperatorToString()", "Unknown compare operator." );
   return QString();
@@ -61,10 +62,10 @@ static QString compareOperatorToString( Query::CompareOperator op )
 static QString logicOperatorToString( Query::LogicOperator op )
 {
   switch ( op ) {
-    case Query::And:
-      return QLatin1String( " AND " );
-    case Query::Or:
-      return QLatin1String( " OR " );
+  case Query::And:
+    return QLatin1String( " AND " );
+  case Query::Or:
+    return QLatin1String( " OR " );
   }
   Q_ASSERT_X( false, "QueryBuilder::logicOperatorToString()", "Unknown logic operator." );
   return QString();
@@ -73,27 +74,27 @@ static QString logicOperatorToString( Query::LogicOperator op )
 static QString sortOrderToString( Query::SortOrder order )
 {
   switch ( order ) {
-    case Query::Ascending:
-      return QLatin1String( " ASC" );
-    case Query::Descending:
-      return QLatin1String( " DESC" );
+  case Query::Ascending:
+    return QLatin1String( " ASC" );
+  case Query::Descending:
+    return QLatin1String( " DESC" );
   }
   Q_ASSERT_X( false, "QueryBuilder::sortOrderToString()", "Unknown sort order." );
   return QString();
 }
 
-QueryBuilder::QueryBuilder( const QString& table, QueryBuilder::QueryType type ) :
-    mTable( table ),
+QueryBuilder::QueryBuilder( const QString &table, QueryBuilder::QueryType type )
+   : mTable( table )
 #ifndef QUERYBUILDER_UNITTEST
-    mDatabaseType( DbType::type( DataStore::self()->database() ) ),
-    mQuery( DataStore::self()->database() ),
+   , mDatabaseType( DbType::type( DataStore::self()->database() ) )
+   , mQuery( DataStore::self()->database() )
 #else
-    mDatabaseType( DbType::Unknown ),
+   , mDatabaseType( DbType::Unknown )
 #endif
-    mType( type ),
-    mIdentificationColumn( QLatin1String("id") ),
-    mLimit( -1 ),
-    mDistinct( false )
+   , mType( type )
+   , mIdentificationColumn( QLatin1String( "id" ) )
+   , mLimit( -1 )
+   , mDistinct( false )
 {
 }
 
@@ -102,7 +103,7 @@ void QueryBuilder::setDatabaseType( DbType::Type type )
   mDatabaseType = type;
 }
 
-void QueryBuilder::addJoin( JoinType joinType, const QString& table, const Query::Condition& condition )
+void QueryBuilder::addJoin( JoinType joinType, const QString &table, const Query::Condition &condition )
 {
   Q_ASSERT( ( joinType == InnerJoin && ( mType == Select || mType == Update ) ) ||
             ( joinType == LeftJoin && mType == Select ) );
@@ -117,26 +118,26 @@ void QueryBuilder::addJoin( JoinType joinType, const QString& table, const Query
   }
 }
 
-void QueryBuilder::addJoin( JoinType joinType, const QString& table, const QString& col1, const QString& col2 )
+void QueryBuilder::addJoin( JoinType joinType, const QString &table, const QString &col1, const QString &col2 )
 {
   Query::Condition condition;
   condition.addColumnCondition( col1, Query::Equals, col2 );
   addJoin( joinType, table, condition );
 }
 
-void QueryBuilder::addValueCondition(const QString & column, Query::CompareOperator op, const QVariant & value, ConditionType type)
+void QueryBuilder::addValueCondition( const QString &column, Query::CompareOperator op, const QVariant &value, ConditionType type )
 {
   Q_ASSERT( type == WhereCondition || ( type == HavingCondition && mType == Select ) );
   mRootCondition[type].addValueCondition( column, op, value );
 }
 
-void QueryBuilder::addColumnCondition(const QString & column, Query::CompareOperator op, const QString & column2, ConditionType type)
+void QueryBuilder::addColumnCondition( const QString &column, Query::CompareOperator op, const QString &column2, ConditionType type )
 {
   Q_ASSERT( type == WhereCondition || ( type == HavingCondition && mType == Select ) );
   mRootCondition[type].addColumnCondition( column, op, column2 );
 }
 
-QSqlQuery& QueryBuilder::query()
+QSqlQuery &QueryBuilder::query()
 {
   return mQuery;
 }
@@ -150,110 +151,113 @@ bool QueryBuilder::exec()
   Query::Condition whereCondition = mRootCondition[WhereCondition];
 
   switch ( mType ) {
-    case Select:
-      statement += QLatin1String( "SELECT " );
-      if ( mDistinct )
-        statement += QLatin1String( "DISTINCT " );
-      if ( mDatabaseType == DbType::Virtuoso && mLimit > 0 )
-        statement += QLatin1Literal( "TOP " ) + QString::number( mLimit ) + QLatin1Char( ' ' );
-      Q_ASSERT_X( mColumns.count() > 0, "QueryBuilder::exec()", "No columns specified" );
-      statement += mColumns.join( QLatin1String( ", " ) );
-      statement += QLatin1String(" FROM ");
-      statement += mTable;
-      Q_FOREACH ( const QString& joinedTable, mJoinedTables ) {
-        const QPair< JoinType, Query::Condition >& join = mJoins.value( joinedTable );
-        switch ( join.first ) {
-          case LeftJoin:
-            statement += QLatin1String( " LEFT JOIN " );
-            break;
-          case InnerJoin:
-            statement += QLatin1String( " INNER JOIN " );
-            break;
-        }
-        statement += joinedTable;
-        statement += QLatin1String( " ON " );
-        statement += buildWhereCondition( join.second );
-      }
-     break;
-    case Insert:
-    {
-      statement += QLatin1String( "INSERT INTO " );
-      statement += mTable;
-      statement += QLatin1String(" (");
-      typedef QPair<QString,QVariant> StringVariantPair;
-      QStringList cols, vals;
-      Q_FOREACH ( const StringVariantPair &p, mColumnValues ) {
-        cols.append( p.first );
-        vals.append( bindValue( p.second ) );
-      }
-      statement += cols.join( QLatin1String( ", " ) );
-      statement += QLatin1String(") VALUES (");
-      statement += vals.join( QLatin1String( ", " ) );
-      statement += QLatin1Char(')');
-      if ( mDatabaseType == DbType::PostgreSQL && !mIdentificationColumn.isEmpty() )
-        statement += QLatin1String( " RETURNING " ) + mIdentificationColumn;
-      break;
+  case Select:
+    statement += QLatin1String( "SELECT " );
+    if ( mDistinct ) {
+      statement += QLatin1String( "DISTINCT " );
     }
-    case Update:
-    {
-      ///TODO: fix joined Update tables for SQLite by using subqueries
-      // put the ON condition into the WHERE part of the UPDATE query
-      Q_FOREACH ( const QString& table, mJoinedTables ) {
-        QPair< JoinType, Query::Condition > join = mJoins.value( table );
-        Q_ASSERT( join.first == InnerJoin );
-        whereCondition.addCondition( join.second );
-      }
-
-      statement += QLatin1String( "UPDATE " );
-      statement += mTable;
-
-      if ( mDatabaseType == DbType::MySQL && !mJoinedTables.isEmpty() ) {
-        // for mysql we list all tables directly
-        statement += QLatin1String( ", " );
-        statement += mJoinedTables.join( QLatin1String( ", " ) );
-      }
-
-      statement += QLatin1String( " SET " );
-      Q_ASSERT_X( mColumnValues.count() >= 1, "QueryBuilder::exec()", "At least one column needs to be changed" );
-      typedef QPair<QString,QVariant> StringVariantPair;
-      QStringList updStmts;
-      Q_FOREACH ( const StringVariantPair &p, mColumnValues ) {
-        QString updStmt = p.first;
-        updStmt += QLatin1String( " = " );
-        updStmt += bindValue( p.second );
-        updStmts << updStmt;
-      }
-      statement += updStmts.join( QLatin1String( ", " ) );
-
-      if ( mDatabaseType == DbType::PostgreSQL && !mJoinedTables.isEmpty() ) {
-        // PSQL have this syntax
-        // FROM t1 JOIN t2 JOIN ...
-        statement += QLatin1String( " FROM " );
-        statement += mJoinedTables.join( QLatin1String( " JOIN " ) );
-      }
-
-      break;
+    if ( mDatabaseType == DbType::Virtuoso && mLimit > 0 ) {
+      statement += QLatin1Literal( "TOP " ) + QString::number( mLimit ) + QLatin1Char( ' ' );
     }
-    case Delete:
-      statement += QLatin1String( "DELETE FROM " );
-      statement += mTable;
-      break;
-    default:
-      Q_ASSERT_X( false, "QueryBuilder::exec()", "Unknown enum value" );
+    Q_ASSERT_X( mColumns.count() > 0, "QueryBuilder::exec()", "No columns specified" );
+    statement += mColumns.join( QLatin1String( ", " ) );
+    statement += QLatin1String( " FROM " );
+    statement += mTable;
+    Q_FOREACH ( const QString &joinedTable, mJoinedTables ) {
+      const QPair<JoinType, Query::Condition> &join = mJoins.value( joinedTable );
+      switch ( join.first ) {
+      case LeftJoin:
+        statement += QLatin1String( " LEFT JOIN " );
+        break;
+      case InnerJoin:
+        statement += QLatin1String( " INNER JOIN " );
+        break;
+      }
+      statement += joinedTable;
+      statement += QLatin1String( " ON " );
+      statement += buildWhereCondition( join.second );
+    }
+    break;
+  case Insert:
+  {
+    statement += QLatin1String( "INSERT INTO " );
+    statement += mTable;
+    statement += QLatin1String( " (" );
+    typedef QPair<QString,QVariant> StringVariantPair;
+    QStringList cols, vals;
+    Q_FOREACH ( const StringVariantPair &p, mColumnValues ) {
+      cols.append( p.first );
+      vals.append( bindValue( p.second ) );
+    }
+    statement += cols.join( QLatin1String( ", " ) );
+    statement += QLatin1String( ") VALUES (" );
+    statement += vals.join( QLatin1String( ", " ) );
+    statement += QLatin1Char( ')' );
+    if ( mDatabaseType == DbType::PostgreSQL && !mIdentificationColumn.isEmpty() ) {
+      statement += QLatin1String( " RETURNING " ) + mIdentificationColumn;
+    }
+    break;
+  }
+  case Update:
+  {
+    ///TODO: fix joined Update tables for SQLite by using subqueries
+    // put the ON condition into the WHERE part of the UPDATE query
+    Q_FOREACH ( const QString &table, mJoinedTables ) {
+      QPair< JoinType, Query::Condition > join = mJoins.value( table );
+      Q_ASSERT( join.first == InnerJoin );
+      whereCondition.addCondition( join.second );
+    }
+
+    statement += QLatin1String( "UPDATE " );
+    statement += mTable;
+
+    if ( mDatabaseType == DbType::MySQL && !mJoinedTables.isEmpty() ) {
+      // for mysql we list all tables directly
+      statement += QLatin1String( ", " );
+      statement += mJoinedTables.join( QLatin1String( ", " ) );
+    }
+
+    statement += QLatin1String( " SET " );
+    Q_ASSERT_X( mColumnValues.count() >= 1, "QueryBuilder::exec()", "At least one column needs to be changed" );
+    typedef QPair<QString,QVariant> StringVariantPair;
+    QStringList updStmts;
+    Q_FOREACH ( const StringVariantPair &p, mColumnValues ) {
+      QString updStmt = p.first;
+      updStmt += QLatin1String( " = " );
+      updStmt += bindValue( p.second );
+      updStmts << updStmt;
+    }
+    statement += updStmts.join( QLatin1String( ", " ) );
+
+    if ( mDatabaseType == DbType::PostgreSQL && !mJoinedTables.isEmpty() ) {
+      // PSQL have this syntax
+      // FROM t1 JOIN t2 JOIN ...
+      statement += QLatin1String( " FROM " );
+      statement += mJoinedTables.join( QLatin1String( " JOIN " ) );
+    }
+
+    break;
+  }
+  case Delete:
+    statement += QLatin1String( "DELETE FROM " );
+    statement += mTable;
+    break;
+  default:
+    Q_ASSERT_X( false, "QueryBuilder::exec()", "Unknown enum value" );
   }
 
   if ( !whereCondition.isEmpty() ) {
-    statement += QLatin1String(" WHERE ");
+    statement += QLatin1String( " WHERE " );
     statement += buildWhereCondition( whereCondition );
   }
 
   if ( !mGroupColumns.isEmpty() ) {
-    statement += QLatin1String(" GROUP BY ");
+    statement += QLatin1String( " GROUP BY " );
     statement += mGroupColumns.join( QLatin1String( ", " ) );
   }
 
   if ( !mRootCondition[HavingCondition].isEmpty() ) {
-    statement += QLatin1String(" HAVING ");
+    statement += QLatin1String( " HAVING " );
     statement += buildWhereCondition( mRootCondition[HavingCondition] );
   }
 
@@ -286,19 +290,33 @@ bool QueryBuilder::exec()
   //too heavy debug info but worths to have from time to time
   //akDebug() << "Executing query" << statement;
   bool isBatch = false;
-  for ( int i = 0; i < mBindValues.count(); ++i )
-  {
+  for ( int i = 0; i < mBindValues.count(); ++i ) {
     mQuery.bindValue( QLatin1Char( ':' ) + QString::number( i ), mBindValues[i] );
-    if ( !isBatch && mBindValues[i].canConvert<QVariantList>() )
+    if ( !isBatch && mBindValues[i].canConvert<QVariantList>() ) {
       isBatch = true;
+    }
     //akDebug() << QString::fromLatin1( ":%1" ).arg( i ) <<  mBindValues[i];
   }
   bool ret;
-  if ( isBatch ) {
-    ret = mQuery.execBatch();
+  if ( StorageDebugger::instance()->isSQLDebuggingEnabled() ) {
+    QTime t;
+    t.start();
+    if ( isBatch ) {
+      ret = mQuery.execBatch();
+    } else {
+      ret = mQuery.exec();
+    }
+    StorageDebugger::instance()->queryExecuted( mQuery, t.elapsed() );
+
   } else {
-    ret = mQuery.exec();
+    StorageDebugger::instance()->incSequence();
+    if ( isBatch ) {
+      ret = mQuery.execBatch();
+    } else {
+      ret = mQuery.exec();
+    }
   }
+
   if ( !ret ) {
     akError() << "Error during executing query" << statement << ": " << mQuery.lastError().text();
     return false;
@@ -309,32 +327,32 @@ bool QueryBuilder::exec()
   return true;
 }
 
-void QueryBuilder::addColumns(const QStringList & cols)
+void QueryBuilder::addColumns( const QStringList &cols )
 {
   mColumns << cols;
 }
 
-void QueryBuilder::addColumn(const QString & col)
+void QueryBuilder::addColumn( const QString &col )
 {
   mColumns << col;
 }
 
-void QueryBuilder::addAggregation(const QString& col, const QString& aggregate)
+void QueryBuilder::addAggregation( const QString &col, const QString &aggregate )
 {
   QString s( aggregate );
-  s += QLatin1Char('(');
+  s += QLatin1Char( '(' );
   s += col;
-  s += QLatin1Char(')');
+  s += QLatin1Char( ')' );
   mColumns.append( s );
 }
 
-QString QueryBuilder::bindValue(const QVariant & value)
+QString QueryBuilder::bindValue( const QVariant &value )
 {
   mBindValues << value;
   return QLatin1Char( ':' ) + QString::number( mBindValues.count() - 1 );
 }
 
-QString QueryBuilder::buildWhereCondition(const Query::Condition & cond)
+QString QueryBuilder::buildWhereCondition( const Query::Condition &cond )
 {
   if ( !cond.isEmpty() ) {
     QStringList conds;
@@ -370,51 +388,51 @@ QString QueryBuilder::buildWhereCondition(const Query::Condition & cond)
   }
 }
 
-void QueryBuilder::setSubQueryMode(Query::LogicOperator op, ConditionType type)
+void QueryBuilder::setSubQueryMode( Query::LogicOperator op, ConditionType type )
 {
   Q_ASSERT( type == WhereCondition || ( type == HavingCondition && mType == Select ) );
   mRootCondition[type].setSubQueryMode( op );
 }
 
-void QueryBuilder::addCondition(const Query::Condition & condition, ConditionType type)
+void QueryBuilder::addCondition( const Query::Condition &condition, ConditionType type )
 {
   Q_ASSERT( type == WhereCondition || ( type == HavingCondition && mType == Select ) );
   mRootCondition[type].addCondition( condition );
 }
 
-void QueryBuilder::addSortColumn(const QString & column, Query::SortOrder order )
+void QueryBuilder::addSortColumn( const QString &column, Query::SortOrder order )
 {
   mSortColumns << qMakePair( column, order );
 }
 
-void QueryBuilder::addGroupColumn(const QString& column)
+void QueryBuilder::addGroupColumn( const QString &column )
 {
   Q_ASSERT( mType == Select );
   mGroupColumns << column;
 }
 
-void QueryBuilder::addGroupColumns(const QStringList& columns)
+void QueryBuilder::addGroupColumns( const QStringList &columns )
 {
   Q_ASSERT( mType == Select );
   mGroupColumns += columns;
 }
 
-void QueryBuilder::setColumnValue(const QString & column, const QVariant & value)
+void QueryBuilder::setColumnValue( const QString &column, const QVariant &value )
 {
   mColumnValues << qMakePair( column, value );
 }
 
-void QueryBuilder::setDistinct(bool distinct)
+void QueryBuilder::setDistinct( bool distinct )
 {
   mDistinct = distinct;
 }
 
-void QueryBuilder::setLimit(int limit)
+void QueryBuilder::setLimit( int limit )
 {
   mLimit = limit;
 }
 
-void QueryBuilder::setIdentificationColumn(const QString& column)
+void QueryBuilder::setIdentificationColumn( const QString &column )
 {
   mIdentificationColumn = column;
 }
@@ -427,10 +445,14 @@ qint64 QueryBuilder::insertId()
     return query().record().value( mIdentificationColumn ).toLongLong();
   } else {
     const QVariant v = query().lastInsertId();
-    if ( !v.isValid() ) return -1;
+    if ( !v.isValid() ) {
+      return -1;
+    }
     bool ok;
     const qint64 insertId = v.toLongLong( &ok );
-    if ( !ok ) return -1;
+    if ( !ok ) {
+      return -1;
+    }
     return insertId;
   }
   return -1;
